from setuptools import setup, find_packages

setup(
    name="axon_networks_beta",
    version="0.0.2",
    description="A beta framework for creating digital twin of supply chain networks",
    author="Antony Alappat",
    author_email="antony.alappat@gmail.com",
    url="",  # Add your GitHub repo
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
